<?php

namespace App\Http\Controllers;

use App\Models\AffiliatedLink;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class AffiliatedLinkController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if($request->ajax()){
            $data = AffiliatedLink::latest()->get();

            return DataTables::of($data)
            ->addIndexColumn()
            ->addColumn('created_at', function ($data) {
                return Carbon::parse($data->created_at)->setTimezone('Asia/Karachi')->toDateTimeString();
            })
            ->addColumn('action', function ($data) {
                $btn = '<a href="' . url("/manager/affiliates/" . $data->id . "/edit") . '" data-toggle="tooltip" data-original-title="Edit" class="btn btn-dropbox btn-sm">
                <i class="icon-pencil" aria-hidden="true"></i>
            </a>

            <a href="' . url("/manager/affiliates/$data->id") . '" data-toggle="tooltip" data-original-title="Info" class="btn btn-info btn-sm m-1">
                <i class="fa fa-eye" aria-hidden="true"></i>
            </a>

            <a href="javascript:void(0)" data-toggle="tooltip" data-id="' . $data->id . '" data-original-title="Delete" class="btn btn-danger m-1 btn-sm deleteAffiliate">
            <i class="icon-trash" aria-hidden="true"></i>
            </a>';
    
            return $btn;
            })
            ->rawColumns(['action'])
            ->make(true);
        }
        
        return view('admin.pages.affiliate.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.affiliate.form');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        AffiliatedLink::create($request->all());
        return redirect()->to('/manager/affiliates')->with('success', 'Created Successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        return view('admin.pages.affiliate.view', [
            'data' => AffiliatedLink::findOrFail($id)
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        return view('admin.pages.affiliate.form', [
            'data' => AffiliatedLink::findOrFail($id)
        ]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        tap(AffiliatedLink::findOrFail($id))->update($request->all());
        return redirect()->to('/manager/affiliates')->with('success', 'Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $affiliate = AffiliatedLink::findOrFail($id);
        $affiliate->delete();

        return response()->json([
            'success' => true, 'msg' => 'Deleted Successfully'
        ]);
    }
}
