<?php

namespace App\Http\Controllers;

use App\Events\SendAction;
use App\Models\Announcement;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class AnnouncementController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {

            $data = Announcement::latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('created_at', function ($data) {
                    return Carbon::parse($data->created_at)->setTimezone('Asia/Karachi')->toDateTimeString();
                })
                ->addColumn('action', function ($data) {
                    return '<a href="javascript:void(0)" data-toggle="tooltip" data-id="' . $data->id . '" data-original-title="Delete" class="btn btn-danger m-1 btn-sm delete">   
                    <i class="icon-trash" aria-hidden="true"></i>
                    </a>';
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('admin.pages.announcement.list');
    }

    public function store(Request $request)
    {
        if ($request->method() === 'GET') {
            return view('admin.pages.announcement.form');
        }

        $input = $request->all();
        $announcement = Announcement::create($input);
        
        $users = User::get()->pluck('id');

        $body = $request->description;    
        event(new SendAction(
            $users->toArray(),
            [User::class],
            [
                'title' => $request->title,
                'body' => $body,
                'object_id' => $announcement->id,
                'object_type' => Announcement::class,
                'actor_id' => auth()->user()->id,
                'type' => 'announcement',
                'object' => 'announcement',
            ],
            null,
            true
        ));

        return redirect()->to('/manager/announcements')->with('success', 'Announcement send successfully');
    }

    public function destroy($id)
    {
        $announcement = Announcement::findOrFail($id);
        $announcement->delete();

        return response()->json([
            'success' => true, 'msg' => 'Announcement deleted successfully'
        ]);
    }
}
