<?php

namespace App\Http\Controllers;

use App\Http\Requests\ChangePasswordRequest;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class AuthController extends Controller
{
    public function login(Request $request)
    {
        if($request->method() == 'GET'){
            return view('/admin.login');
        }

        $user = User::whereEmail($request->email)->first();
        if(!$user){
            return redirect()->back()->with('error', 'User not found');
        }

        if (!Auth::attempt($request->only('email', 'password')) || Auth::user()->type !== 'admin') {
            return redirect()->back()->with('error', 'Email or password is invalid');
        }        

        return redirect()->to('/manager/dashboard')->with('success', 'You have been logged in successfully');
    }

    public function logout()
    {
        auth()->logout();
        return redirect()->to('/manager/dashboard')->with('success', 'You have been successful logged out');
    }

    public function updateCredential(ChangePasswordRequest $request)
    {
        $user = User::find(auth()->user()->id);

        if (!Hash::check($request->current_password, $user->password)) {
            return redirect()->back()->with('error', 'Your current password is incorrect');
        }

        if (!Hash::check($user['password'], $user['password'])) {
            return redirect()->back()->with('error', 'Your new password must be different from the old password');
        }

        $user->password = $request->password;
        $user->save();

        return redirect()->back()->with('success', 'Password updated successfully');
    }
}
