<?php

namespace App\Http\Controllers;

use App\Events\SendAction;
use App\Models\Community;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class CommunityController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = Community::with('user')->latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('created_at', function ($data) {
                    return Carbon::parse($data->created_at)->setTimezone('Asia/Karachi')->toDateTimeString();
                })
                ->addColumn('action', function ($data) {
                    $btn = '
                    <a href="' . url("/manager/communities/$data->id") . '" data-toggle="tooltip" data-original-title="Info" class="btn btn-info btn-sm m-1">
                        <i class="fa fa-eye" aria-hidden="true"></i>
                    </a>';

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('admin.pages.community.list');
    }

    public function show($id)
    {
        return view('admin.pages.community.view', [
            'data' => Community::with('communityMember')->findOrFail($id)
        ]);
    }

    public function update(Request $request, $id)
    {
        $community = Community::findOrFail($id);

        if ($request->status == 1 || $request->status == 2) {
            $body = $request->status == 1 ? 'Your PTA has been approved' : 'Your PTA has been rejected';

            // Dispatching the event
            event(new SendAction(
                [$community->user_id],
                [User::class],
                [
                    'title' => $request->status == 1 ? 'PTA Approved' : 'PTA Rejected',
                    'body' => $body,
                    'object_id' => $community->id,
                    'object_type' => Community::class,
                    'actor_id' => auth()->user()->id,
                    'type' => $request->status == 1 ? 'approved' : 'disapproved',
                    'object' => 'community',
                ]
            ));

            // Update community status
            $community->update(['status' => $request->status]);
            // Update user status
            $community->user()->update(['status' => $request->status]);
        }

        return redirect()->to('/manager/communities')->with('success', 'Updated successfully');
    }
}
