<?php

namespace App\Http\Controllers;

use App\Events\SendAction;
use App\Models\Course;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class CourseController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = Course::latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('created_at', function ($data) {
                    return Carbon::parse($data->created_at)->setTimezone('Asia/Karachi')->toDateTimeString();
                })
                ->addColumn('action', function ($data) {
                    $btn = '<a href="' . url("/manager/courses/" . $data->id . "/edit") . '" data-toggle="tooltip" data-original-title="Edit" class="btn btn-dropbox btn-sm">
                <i class="icon-pencil" aria-hidden="true"></i>
            </a>

            <a href="' . url("/manager/courses/$data->id") . '" data-toggle="tooltip" data-original-title="Info" class="btn btn-info btn-sm m-1">
                <i class="fa fa-eye" aria-hidden="true"></i>
            </a>

            <a href="javascript:void(0)" data-toggle="tooltip" data-id="' . $data->id . '" data-original-title="Delete" class="btn btn-danger m-1 btn-sm deleteCourse">
            <i class="icon-trash" aria-hidden="true"></i>
            </a>';

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('admin.pages.course.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.course.form');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $users = User::get()->pluck('id');
        $course = Course::create($request->all());

        $body = $request->name;
        event(new SendAction(
            $users->toArray(),
            [User::class],
            [
                'title' => 'New Course',
                'body' => $body,
                'object_id' => $course->id,
                'object_type' => Course::class,
                'actor_id' => auth()->user()->id,
                'type' => 'courses',
                'object' => 'courses',
            ],
            null,
            true
        ));
        
        return redirect()->to('/manager/courses')->with('success', 'Created Successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        return view('admin.pages.course.view', [
            'data' => Course::findOrFail($id)
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        return view('admin.pages.course.form', [
            'data' => Course::findOrFail($id)
        ]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        tap(Course::findOrFail($id))->update($request->all());
        return redirect()->to('/manager/courses')->with('success', 'Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $course = Course::findOrFail($id);
        $course->delete();

        return response()->json([
            'success' => true, 'msg' => 'Deleted Successfully'
        ]);
    }
}
