<?php

namespace App\Http\Controllers;

use App\Models\Event;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class EventController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $event = Event::get(['id', 'name', 'description', 'image', 'start_date', 'end_date']);
            return response()->json($event);
        }

        return view('admin.pages.event.form');
    }

    /**
     * undocumented function summary
     *
     * Undocumented function long description
     *
     * @param Type $var Description
     * @return type
     * @throws conditon
     **/
    public function store(Request $request)
    {
        switch ($request->type) {
            case 'create':
                $event = Event::create([
                    'name' => $request->name,
                    'start_date' => $request->date,
                    'end_date' => $request->end_date,
                    'image' => $request->image,
                    'description' => $request->description
                ]);

                return response()->json($event);
                break;

            case 'update':
                $event = Event::find($request->id)->update([
                    'name' => $request->name,
                    'start_date' => $request->date,
                    'end_date' => $request->end_date,
                    'image' => $request->image,
                    'description' => $request->description
                ]);

                return response()->json($event);
                break;

            case 'delete':
                $event = Event::find($request->id)->delete();
                return response()->json($event);
                break;

            default:
                # code...
                break;
        }
    }

    public function eventParticipate()
    {
        if (request()->ajax()) {
            $data = Event::latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('created_at', function ($data) {
                    return Carbon::parse($data->created_at)->setTimezone('Asia/Karachi')->toDateTimeString();
                })
                ->addColumn('action', function ($data) {
                    $btn = '
                    <a href="' . url("/manager/events/participates/$data->id") . '" data-toggle="tooltip" data-original-title="Info" class="btn btn-info btn-sm m-1">
                        <i class="fa fa-eye" aria-hidden="true"></i>
                    </a>';

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('admin.pages.event.participate');
    }

    public function participateShow($id)
    {
        return view('admin.pages.event.view', [
            'data' => Event::with('eventParticipate')->findOrFail($id)
        ]);
    }
}
