<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class AffiliatedLink extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'title',
        'slug',
        'url',
        'image'
    ];

    /**
     * The booted method of the model
     */
    protected static function booted()
    {
        static::creating(function ($affiliated) {
            $affiliated->slug = Str::slug($affiliated->title, '-');
        });
    }

    protected $appends = [
        'image_url'
    ];

    public function getImageUrlAttribute()
    {
        return !is_null($this->image) ? env('UPLOADS_URL') . $this->image : null;
    }

    public function setImageAttribute($image)
    {
        if (is_file($image)) {
            $this->attributes['image'] = $image ?
                Storage::disk(env('DISK'))->put('affiliate', $image) : null;
        }
    }
}
