<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage;

class Content extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'title',
        'slug',
        'description',
        'image'
    ];

    protected $appends = [
        'image_url'
    ];

    public function getImageUrlAttribute()
    {
        return !is_null($this->image) ? env('UPLOADS_URL') . $this->image : null;
    }

    public function setImageAttribute($image)
    {
        if (is_file($image)) {
            $this->attributes['image'] = $image ?
                Storage::disk(env('DISK'))->put('content', $image) : null;
        }
    }

    public function contentImage()
    {
        return $this->hasMany(ContentImage::class);
    }
}
