<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage;

class Event extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'name',
        'description',
        'image',
        'start_date',
        'end_date'
    ];

    protected $appends = [
        'image_url'
    ];

    public function getImageUrlAttribute()
    {
        return !is_null($this->image) ? env('UPLOADS_URL') . $this->image : null;
    }

    public function setImageAttribute($image)
    {
        if (is_file($image)) {
            $this->attributes['image'] = $image ?
                Storage::disk(env('DISK'))->put('event', $image) : null;
        }
    }

    public function eventParticipate()
    {
        return $this->hasMany(EventParticipate::class);
    }
}
