<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Laravel\Sanctum\HasApiTokens;
use Illuminate\Support\Str;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'first_name',
        'last_name',
        'email',
        'password',
        'phone',
        'profile_image',
        'social_id',
        'social_type',
        'send_code',
        'code_verified_at',
        'country_flag',
        'country_code'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    protected $appends = ['profile_image_url'];

    public function getProfileImageUrlAttribute()
    {
        return !is_null($this->profile_image) ? env('UPLOADS_URL') . $this->profile_image : null;
    }

    public function setProfileImageAttribute($profile_image)
    {
        if (is_file($profile_image)) {
            $this->attributes['profile_image'] = $profile_image ?
                Storage::disk(env('DISK'))->put('profile', $profile_image) : null;
        }
    }

    public function setPasswordAttribute($password)
    {
        return $this->attributes['password'] = Hash::make($password);
    }

    public function devices()
    {
        return $this->hasMany(UserDevice::class);
    }

    public function userDevices($request, $access_token)
    {
        $request['access_token'] = $access_token;
        $this->devices()->updateOrCreate(
            $request->only('udid'),
            $request->all()
        );
    }

    public function eventParticipate()
    {
        return $this->hasMany(EventParticipate::class);
    }
}
