@extends('admin.layouts.main')

@section('content')
<div class="page-wrapper">
    <!-- ============================================================== -->
    <!-- Container fluid  -->
    <!-- ============================================================== -->
    <div class="container-fluid">
        <!-- ============================================================== -->
        <!-- Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">{{ @$data ? 'Edit' : 'Add' }} Affiliate Link</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ url('s/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">
                            <a href="{{ url('/affiliates') }}" class="text-danger">Affiliate Link</a>
                        </li>
                    </ol>
                </div>
            </div>
        </div>

        @include('admin.includes.alert')
        <div class="card">
            <div class="card-body">

                <form action="{{ @$data ? url('/manager/affiliates/' . $data['id']  ) : url('/manager/affiliates') }}" method="post" enctype="multipart/form-data" data-parsley-validate>
                    @csrf

                    @if( @$data )
                    @method('PATCH')
                    @endif

                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label class="control-label">Affiliate Title<span class="text-danger">*</span> </label>
                            <input type="text" data-parsley-required-message="The title field is required" name="title" value="{{ old('title', @$data->title) }}" class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" autocomplete="off" placeholder="Enter title" required>
                            @if ($errors->has('title'))
                            <span class="text-danger">{{ $errors->first('title') }}</span>
                            @endif
                        </div>

                        <div class="col-md-6 mb-3">
                            <label class="control-label">Affiliate Link<span class="text-danger">*</span></label>
                            <input type="url" class="form-control" id="url" name="url" value="{{ old('url', @$data['url']) }}" data-parsley-required-message="The link field is required" data-parsley-type="url" data-parsley-pattern="^(https?://)?(www\.)?[\w-]+(\.[\w-]+)+(/[\w-./?%&=]*)?$" placeholder="Enter link" required>
                            @if ($errors->has('url'))
                            <span class="text-danger">{{ $errors->first('url') }}</span>
                            @endif
                        </div>

                        <div class="col-md-6 mb-3">
                            <label class="control-label">Affiliate Image<span class="text-danger">*</span></label>
                            <div>
                                <label for="affiliate-image" style="cursor: pointer;">
                                    <img id="previewImg" src="{{ @$data->image_url != '' ? @$data->image_url : url('assets/images/upload.jpg') }}" alt="logo" class="mb-3" id="showUpload" style="width: 150px;height: 150px">
                                </label>
                            </div>
                            <input type="file" name="image" data-parsley-required-message="The image field is required" class="form-control upload-image" id="affiliate-image" style="display: none;" {{ @$data->image_url == null ? 'required' : '' }}>
                            @if ($errors->has('image'))
                            <span class="text-danger">{{ $errors->first('image') }}</span>
                            @endif
                        </div>

                    </div>

                    <button class="btn btn-primary" type="submit">Save</button>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection

@push('script')
<script>
    $(".upload-image").change(function() {
        var inputFile = $(this).parent().children('div').children('label').children('img')
        var reader = new FileReader();
        reader.onload = function(e) {
            inputFile.attr('src', e.target.result);
        };
        reader.readAsDataURL(this.files[0]);
        console.log(this.files[0])
    });

    function previewFile(input) {
        var file = $("input[type=file]").get(0).files[0];
        if (file) {
            var reader = new FileReader();
            reader.onload = function() {
                $("#previewImg").attr("src", reader.result);
            }
            reader.readAsDataURL(file);
        }
    }
</script>
@endpush