@extends('admin.layouts.main')

@section('content')

<div class="page-wrapper">
    <!-- ============================================================== -->
    <!-- Container fluid  -->
    <!-- ============================================================== -->
    <div class="container-fluid">
        <!-- ============================================================== -->
        <!-- Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">Communities</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item active"><a href="{{ url('/manager/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">
                            <a href="{{ url('/manager/communities') }}" class="text-info">Community</a>
                        </li>
                    </ol>
                </div>
            </div>
        </div>
        <!-- ============================================================== -->
        <!-- End Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        @include('admin.includes.alert')

        <div class="card">
            <div class="card-body">
                <div class="table-responsive m-t-30">
                    <table class="table table-bordered" id="communities">
                        <thead>
                            <tr>
                                <th width="50">S.no</th>
                                <th>Full Name</th>
                                <th>Name</th>
                                <th>Email</th>
                                <th>Phone</th>
                                <th>Type</th>
                                <th>Status</th>
                                <th>Date</th>
                                <th width="100px">Action</th>
                            </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@push('script')
<script>
    $(document).ready(function() {
        $(function() {
            $('table').on('draw.dt', function() {
                $('[data-toggle="tooltip"]').tooltip();
            })

            $.ajaxSetup({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                }
            });

            var communities = $('#communities').DataTable({
                processing: true,
                serverSide: true,
                responsive: true,
                orderable: false,
                searchable: true,
                "language": {
                    processing: '<i class="fa fa-spinner fa-spin fa-3x fa-fw"></i><span class="sr-only">Loading...</span>'
                },
                ajax: "",
                columns: [{
                    data: 'DT_RowIndex',
                    name: 'DT_RowIndex',
                    orderable: false,
                    searchable: false
                }, {
                    data: 'user.first_name',
                    render: function ( data, type, row ) {
                    return  data + ' ' + row.user.last_name;
                    } 
                }, {
                    data: 'name',
                    name: 'name'
                }, {
                    data: 'email',
                    name: 'email'
                }, {
                    data: 'phone',
                    name: 'phone'
                }, {
                    data: 'type',
                    render: function(data) {
                        if (data == 'parent') {
                            return '<label class="badge badge-success">Parent</label>';
                        } else if (data == 'teacher') {
                            return '<label class="badge badge-info">Teacher</label>';
                        } else {
                            return '-';
                        }
                    }
                }, {
                    data: 'status',
                    render: function(data) {
                        if (data == '0') {
                            return '<label class="badge badge-warning">Pending</label>';
                        } else if (data == '1') {
                            return '<label class="badge badge-info">Approved</label>';
                        } else if (data == '2') {
                            return '<label class="badge badge-danger">Rejected</label>';
                        }else {
                            return '-';
                        }
                    }
                }, {
                    data: 'created_at',
                    name: 'created_at'
                }, {
                    defaultContent: "",
                    data: "action",
                    name: "action",
                    title: "Action",
                    render: null,
                    orderable: false,
                    searchable: false
                }]
            });
        })
    })
</script>
@endpush