@extends('admin.layouts.main')

@section('content')

<div class="page-wrapper">
    <div class="container-fluid">
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">Community Details</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ url('/manager/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">
                            <a href="{{ url('/manager/communities') }}" class="text-cyan">Communities</a>
                        </li>
                        <li class="breadcrumb-item">Community View</li>
                    </ol>
                </div>
            </div>
        </div>

        <!-- Post -->
        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header bg-inverse text-white">
                        <h4 class="m-b-0 text-white d-inline-block">Community ({{ ucwords($data->type)}})</h4>
                    </div>

                    <div class="ribbon-wrapper card-body collapse show">
                        <div class="row">
                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Type:</b>
                                    @switch($data->type)
                                    @case('parent')
                                    <label class="badge badge-dark">Parent</label>
                                    @break
                                    @case('teacher')
                                    <label class="badge badge-info">Teacher</label>
                                    @break

                                    @default
                                    <label class="badge badge-success">-</label>
                                    @endswitch
                                </p>
                            </div>

                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Status:</b>
                                    @switch($data->status)
                                    @case('0')
                                    <label class="badge badge-warning">Pending</label>
                                    @break
                                    @case('1')
                                    <label class="badge badge-info">Approved</label>
                                    @break
                                    @case('2')
                                    <label class="badge badge-danger">Rejected</label>
                                    @break

                                    @default
                                    <label class="badge badge-success">-</label>
                                    @endswitch
                                </p>
                            </div>

                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Name:</b> {{ $data->name }}</p>
                            </div>

                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Email:</b> {{ $data->email }}</p>
                            </div>

                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Phone:</b> {{ $data->phone }}</p>
                            </div>

                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Amount:</b> {{ $data->amount }}</p>
                            </div>

                            <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Membership:</b> {{ $data->membership }}</p>
                            </div>

                            <!-- <div class="offset-1 col-md-4 p-2">
                                <p class="card-text"><b>Transaction Type:</b> {{ $data->transaction_type }}</p>
                            </div> -->
                        </div>

                        <div class="col-md-12 col-xs-12 b-r p-3">
                                <form class="form-horizontal" action="{{ url('/manager/communities/'.$data->id.'/update') }}" method="post">
                                    @csrf
                                    <div class="col-sm-6">
                                        <div class="form-group">
                                            <select class="form-control form-control-line" name="status">
                                                <option value="0" {{ $data->status == '0' ? 'selected' : '' }}>Pending</option>
                                                <option value="1" {{ $data->status == '1' ? 'selected' : '' }}>Approve</option>
                                                <option value="2" {{ $data->status == '2' ? 'selected' : '' }}>Reject</option>
                                            </select>
                                        </div>
                                    </div>
                                    <div class="col-sm-3">
                                        <div class="form-group">
                                            <button class="btn btn-success">Update</button>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        

                        <hr>
                        <p class="card-text"><b>Created at:</b> {{ \Carbon\Carbon::parse($data->created_at)->setTimezone('Asia/Karachi')->toDateTimeString() }}</p>
                    </div>
                </div>
            </div>

            <!-- Parent/Adult And Child -->
            @if($data->type == 'parent')
            <div class="col-md-12">
                <div class="card">
                    <div class="card-body">
                        <div class="card-header bg-inverse text-white">
                            <h4 class="m-b-0 text-white d-inline-block">Community Member's</h4>
                        </div>
                        <div class="table-responsive">
                            <table class="table table-bordered">
                                <thead>
                                    <tr>
                                        <th>Name</th>
                                        <th>Email</th>
                                        <th>Phone</th>
                                        <th>Type</th>
                                        <th>Grade</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach($data->communityMember as $key => $cm)
                                    <tr>
                                        <td>{{ $cm->name }}</td>
                                        <td>{{ $cm->email }}</td>
                                        <td>{{ $cm->phone }}</td>
                                        <td>{{ $cm->type }}</td>
                                        <td>{{ $cm->grade ?? '-' }}</td>
                                    </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            @endif

        </div>
        <!-- End Row -->
    </div>
</div>

@endsection