@extends('admin.layouts.main')

@section('content')

<div class="page-wrapper">
    <!-- ============================================================== -->
    <!-- Container fluid  -->
    <!-- ============================================================== -->
    <div class="container-fluid">
        <!-- ============================================================== -->
        <!-- Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">Courses</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item active"><a href="{{ url('/manager/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">
                            <a href="{{ url('/manager/courses') }}" class="text-info">Courses</a>
                        </li>
                    </ol>
                    <a href="{{ url('/manager/courses/create') }}" type="button" class="btn btn-info d-xs-block m-l-15">
                        <i class="fa fa-plus-circle"></i> Add Course
                    </a>
                </div>
            </div>
        </div>
        <!-- ============================================================== -->
        <!-- End Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        @include('admin.includes.alert')

        <div class="card">
            <div class="card-body">
                <div class="table-responsive m-t-30">
                    <table class="table table-bordered" id="courses">
                        <thead>
                            <tr>
                                <th width="50">S.no</th>
                                <th>Name</th>
                                <th>Link</th>
                                <th>Type</th>
                                <th>Date</th>
                                <th width="100px">Action</th>
                            </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@push('script')
<script>
    $(document).ready(function() {
        $(function() {
            $('table').on('draw.dt', function() {
                $('[data-toggle="tooltip"]').tooltip();
            })

            $.ajaxSetup({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                }
            });

            var course = $('#courses').DataTable({
                processing: true,
                serverSide: true,
                responsive: true,
                orderable: false,
                searchable: true,
                "language": {
                    processing: '<i class="fa fa-spinner fa-spin fa-3x fa-fw"></i><span class="sr-only">Loading...</span>'
                },
                ajax: "",
                columns: [{
                    data: 'DT_RowIndex',
                    name: 'DT_RowIndex',
                    orderable: false,
                    searchable: false
                }, {
                    data: 'name',
                    name: 'name'
                }, {
                    data: 'url',
                    render: function(data) {
                            if (data == null) {
                                return 'No Link';
                            }
                            return '<a href="' + data + '" class="btn btn-dropbox btn-sm" data-abc="true" target="_blank"> <i class = "fa fa-link" ></a>';
                        }
                }, {
                    data: 'type',
                    render: function(data) {
                        if (data == 'popular') {
                            return '<label class="badge badge-success">Popular</label>';
                        } else if (data == 'recommend') {
                            return '<label class="badge badge-info">Recommend</label>';
                        } else {
                            return '-';
                        }
                    }
                }, {
                    data: 'created_at',
                    name: 'created_at'
                }, {
                    defaultContent: "",
                    data: "action",
                    name: "action",
                    title: "Action",
                    render: null,
                    orderable: false,
                    searchable: false
                }]
            });
        })

        $('body').on('click', '.deleteCourse', function(e) {
            e.preventDefault()
            var id = $(this).data("id");
            swal({
                title: "Are you sure?",
                text: "You will not be able to recover this record!",
                type: "warning",
                showCancelButton: true,
                confirmButtonClass: "btn-danger",
                confirmButtonText: "Yes, delete it!",
                cancelButtonText: "No, Cancel!",
                closeOnConfirm: true,
                closeOnCancel: false
            }).then(function(result) {
                if (result.value) {
                    $.ajax({
                        type: 'DELETE',
                        url: `{{ url('/manager/courses/${id}') }}`,
                        data: {
                            id: id
                        },
                        dataType: 'json',
                        success: function(data) {
                            if (data.success === true) {
                                swal(data.msg, "", "success");
                                setTimeout(function() {
                                    location.reload();
                                }, 2000);
                            } else {
                                swal("Error!", data.msg, "error");
                            }
                        }
                    });

                } else {
                    swal.fire("Cancelled", "Delete Cancelled", "error");
                }
            });
        });
    })
</script>
@endpush