@extends('admin.layouts.main')

@section('content')

<div class="page-wrapper">
    <!-- ============================================================== -->
    <!-- Container fluid  -->
    <!-- ============================================================== -->
    <div class="container-fluid">
        <!-- ============================================================== -->
        <!-- Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">Event</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item active"><a href="{{ url('/manager/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">
                            <a href="{{ url('/manager/events') }}" class="text-info">Event</a>
                        </li>
                    </ol>
                </div>
            </div>
        </div>
        <!-- ============================================================== -->
        <!-- End Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        @include('admin.includes.alert')

        <div class="card">
            <div class="card-body">
                <div id="calendar"></div>
            </div>
        </div>

        <div id="calendarModal" class="modal fade">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="font-weight-bold modal-title" id="exampleModalLabel">Event Calendar</h5>
                        <button type="button" class="close" data-dismiss="modal"><span aria-hidden="true">×</span> <span class="sr-only">close</span></button>
                        <h4 id="modalTitle" class="modal-title"></h4>
                    </div>
                    <form id="calendarForm" enctype="multipart/form-data">
                        @csrf
                        <div id="modalBody" class="modal-body">
                            <div class="form-group">
                                <label for="name" class="col-form-label">Title:</label>
                                <input type="hidden" name="eventDate" id="date">
                                <input type="hidden" name="eventId">
                                <input type="text" class="form-control" name="eventName" id="name" required>
                            </div>
                            <div class="form-group">
                                <label for="name" class="col-form-label">Image:</label>
                                <input type="file" class="form-control" name="image" id="eventImage" required accept=".jpg,.jpeg,.png">
                            </div>
                            <div class="form-group">
                                <label for="name" class="col-form-label">End Date:</label>
                                <input type="date" class="form-control" name="end_date" id="eventEndDate" required>
                            </div>
                            <div class="form-group">
                                <label for="name" class="col-form-label">Description:</label>
                                <textarea class="form-control" name="description" id="eventDescription" data-parsley-required-message="The description field is required" data-parsley-errors-container="#description-errors" rows="6" placeholder="Enter description" required></textarea>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="submit" class="btn btn-primary" id="submitButton">Save</button>
                            <!-- <button class="btn btn-danger" id="delete-event">Delete</button> -->
                        </div>
                    </form>
                </div>
            </div>
        </div>

    </div>
</div>
@endsection
@push('script')

<script src='https://cdn.jsdelivr.net/npm/fullcalendar@6.1.6/index.global.min.js'></script>
<script src='https://unpkg.com/tooltip.js/dist/umd/tooltip.min.js'></script>
<script src='https://unpkg.com/popper.js/dist/umd/popper.min.js'></script>

<script>
    var calendar;
    var event = null;
    $(document).ready(function() {
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });
        var calendarEl = document.getElementById('calendar');
        calendar = new FullCalendar.Calendar(calendarEl, {
            initialView: 'dayGridMonth',
            eventRender: function(info) {
                console.log(info)
                var tooltip = new Tooltip(info.el, {
                    title: info.event.extendedProps.description,
                    placement: 'top',
                    trigger: 'hover',
                    container: 'body'
                });
            },
            selectable: true,
            selectHelper: true,
            select: function(start_date) {
                // console.log(date_time.start);

                $("#calendarForm").trigger("reset");
                $('#calendarModal').modal('show');
                $('[name=eventDate]').val(moment(start_date.start).format('YYYY-MM-DD'))
            },
            eventClick: (e) => {
                $('#calendarModal').modal('show');
                const data = e.event._def.extendedProps.event;
                console.log(data);
                $('[name=eventId]').val(data.id);
                $('[name=eventDate]').val(data.date);
                $('[name=end_date]').val(data.end_date);
                $('[name=eventName]').val(data.name);
                $('[name=image]').val(data.image);
                $('#eventDescription').val(data.description);
                event = e;
            }
        });

        $('#delete-event').click(function(e) {
            e.preventDefault();
            const id = $('[name=eventId]').val();
            console.log(id)
            var event = calendar.getEventById(id);
            $.ajax({
                url: `{{ url('manager/event/store') }}`,
                type: 'DELETE',
                success: function(data) {
                    $('#calendarModal').modal('hide');
                    displayMessage("Event deleted successfully");
                },
            })
        });

        calendar.render();

        // GET ALL EVENT
        $.ajax({
            method: 'GET',
            url: "{{ url('/manager/events') }}",
            dataType: 'json',
            success: function(data) {
                console.log(data)
                data.forEach(function(i) {
                    calendar.addEvent({
                        title: i.name,
                        event: i,
                        date: moment(i.start_date).format('YYYY-MM-DD')
                    })
                });
            },
            error: function(data) {
                alert("Event Calendar Error");
                return false;
            },
        });

        // form submit
        $('#calendarForm').submit(function(e) {
            e.preventDefault();

            const id = $('[name=eventId]').val();

            var formData = new FormData();
            formData.append('id', id);
            formData.append('name', $('[name=eventName]').val());
            formData.append('date', $('[name=eventDate]').val());
            formData.append('end_date', $('[name=end_date]').val());
            formData.append('image', $('[name=image]')[0].files[0]); // Assuming image is a file input
            formData.append('description', $('#eventDescription').val());
            formData.append('type', id ? 'update' : 'create');

            $.ajax({
                url: "{{ url('/manager/event/store') }}",
                type: "POST",
                data: formData,
                processData: false, // Prevent jQuery from processing the data
                contentType: false, // Prevent jQuery from setting content type
                success: function(data) {
                    $('#calendarModal').modal('hide');
                    displayMessage("Event created successfully");

                    if (id) {
                        location.reload();
                    } else {
                        calendar.addEvent({
                            title: data.name,
                            event: data,
                            date: moment(data.start_date).format('YYYY-MM-DD')
                        });
                    }
                },
            });

        })

        function displayMessage(message) {
            toastr.success(message, 'Event');
        }
    });
</script>
@endpush