@extends('admin.layouts.main')

@section('content')
<div class="page-wrapper">
    <!-- ============================================================== -->
    <!-- Container fluid  -->
    <!-- ============================================================== -->
    <div class="container-fluid">
        <!-- ============================================================== -->
        <!-- Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">{{ @$data ? 'Edit' : 'Add' }} Program</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ url('/manager/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">
                            <a href="{{ url('/manager/programs') }}" class="text-danger">Program</a>
                        </li>
                    </ol>
                </div>
            </div>
        </div>

        @include('admin.includes.alert')
        <div class="card">
            <div class="card-body">

                <form action="{{ @$data ? url('/manager/programs/' . $data['id']  ) : url('/manager/programs') }}" method="post" enctype="multipart/form-data" data-parsley-validate>
                    @csrf

                    @if( @$data )
                    @method('PATCH')
                    @endif

                    <div class="row">

                        <div class="col-md-4 mb-3">
                            <label class="control-label">Program Parent</label>
                            <select name="parent_id" data-parsley-required-message="The parent field is required" class="form-control {{ $errors->has('parent_id') ? 'is-invalid' : '' }}">
                                <option value="">Choose Parent</option>
                                @foreach ($programs as $program)
                                <option value="{{ $program->id }}" {{ $program->id === @$data['parent_id'] ? 'selected' : '' }}>{{ $program->title }}</option>
                                @endforeach
                            </select>
                            @if ($errors->has('type'))
                            <span class="text-danger">{{ $errors->first('type') }}</span>
                            @endif
                        </div>

                        <div class="col-md-4 mb-3">
                            <label class="control-label">Program Title<span class="text-danger">*</span> </label>
                            <input type="text" data-parsley-required-message="The program title field is required" name="title" value="{{ old('title', @$data->title) }}" class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" autocomplete="off" placeholder="Enter program title" required>
                            @if ($errors->has('title'))
                            <span class="text-danger">{{ $errors->first('title') }}</span>
                            @endif
                        </div>

                        <div class="col-md-4 mb-3">
                            <label class="control-label">Program Link</label>
                            <input type="text" class="form-control" id="url" name="url" value="{{ old('url', @$data['url']) }}" data-parsley-required-message="The link field is required" data-parsley-type="url" data-parsley-pattern="^https?://[\w-]+(\.[\w-]+)+(/[\w-./?%&=]*)?$" placeholder="Enter link">
                            @if ($errors->has('url'))
                            <span class="text-danger">{{ $errors->first('url') }}</span>
                            @endif
                        </div>

                        <div class="col-md-4 mb-3">
                            <label class="control-label">Program Image<span class="text-danger">*</span></label>
                            <div>
                                <label for="affiliate-image" style="cursor: pointer;">
                                    <img id="previewImg" src="{{ @$data->image_url != '' ? @$data->image_url : url('assets/images/upload.jpg') }}" alt="logo" class="mb-3" id="showUpload" style="width: 150px;height: 150px">
                                </label>
                            </div>
                            <input type="file" name="image" data-parsley-required-message="The image field is required" class="form-control upload-image" id="affiliate-image" style="display: none;" {{ @$data->image_url == null ? 'required' : '' }}>
                            @if ($errors->has('image'))
                            <span class="text-danger">{{ $errors->first('image') }}</span>
                            @endif
                        </div>

                        <div class="col-md-8 mb-3">
                            <label class="control-label">Program Description</label>
                            <textarea class="form-control" id="ckeditor" name="description" rows="6" data-parsley-required-message="The description field is required" placeholder="Enter description">{!! old('description', @$data['description']) !!}</textarea>
                            @if ($errors->has('description'))
                            <span class="text-danger">{{ $errors->first('description') }}</span>
                            @endif
                        </div>

                    </div>

                    <button class="btn btn-primary" type="submit">Save</button>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection

@push('script')
<script>
    $(".upload-image").change(function() {
        var inputFile = $(this).parent().children('div').children('label').children('img')
        var reader = new FileReader();
        reader.onload = function(e) {
            inputFile.attr('src', e.target.result);
        };
        reader.readAsDataURL(this.files[0]);
        console.log(this.files[0])
    });

    function previewFile(input) {
        var file = $("input[type=file]").get(0).files[0];
        if (file) {
            var reader = new FileReader();
            reader.onload = function() {
                $("#previewImg").attr("src", reader.result);
            }
            reader.readAsDataURL(file);
        }
    }

    $(document).ready(function() {
        CKEDITOR.replace('ckeditor');
        CKEDITOR.config = {
            autoUpdateElement: true,
        }

        CKEDITOR.on('instanceReady', function() {
            // $('#ckeditor').attr('required', '');
            $.each(CKEDITOR.instances, function(instance) {
                CKEDITOR.instances[instance].on("change", function(e) {
                    for (instance in CKEDITOR.instances) {
                        CKEDITOR.instances[instance].updateElement();
                        $('form').parsley().validate();
                    }
                });
            });
        });
    });
</script>
@endpush