@extends('admin.layouts.main')

@section('content')
<div class="page-wrapper">
    <!-- ============================================================== -->
    <!-- Container fluid  -->
    <!-- ============================================================== -->
    <div class="container-fluid">
        <!-- ============================================================== -->
        <!-- Bread crumb and right sidebar toggle -->
        <!-- ============================================================== -->
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor font-bold">User Profile</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ url('manager/dashboard') }}">Home</a></li>
                        <li class="breadcrumb-item active">User Profile</li>
                    </ol>
                </div>
            </div>
        </div>

        @include('admin.includes.alert')
        <!-- Change Password -->
        <div class="row">

            <div class="col-md-6">
                <div class="card">
                    <div class="card-header bg-inverse text-white">
                        <h4 class="m-b-0 text-white d-inline-block">Edit Profile</h4>
                    </div>

                    <div class="card-body">

                        <form class="form-horizontal" action="{{ url('/manager/settings/' . @$user->id ) }}" method="POST" data-parsley-validate>
                            @csrf
                            @method('PATCH')

                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label class="control-label">First Name*</label>
                                    <input type="text" data-parsley-required-message="The first name field is required" name="first_name" value="{{ old('first_name', $user->first_name) }}" class="form-control {{ $errors->has('first_name') ? 'is-invalid' : '' }}" autocomplete="off" placeholder="Enter Restaurant first_name" required>
                                    @if ($errors->has('first_name'))
                                    <span class="text-danger">{{ $errors->first('first_name') }}</span>
                                    @endif
                                </div>

                                <div class="col-md-6 mb-3">
                                    <label class="control-label">Last Name*</label>
                                    <input type="text" data-parsley-required-message="The last name field is required" name="last_name" value="{{ old('last_name', $user->last_name) }}" class="form-control {{ $errors->has('last_name') ? 'is-invalid' : '' }}" autocomplete="off" placeholder="Enter Restaurant last_name" required>
                                    @if ($errors->has('last_name'))
                                    <span class="text-danger">{{ $errors->first('last_name') }}</span>
                                    @endif
                                </div>

                                <div class="col-md-6 mb-3">
                                    <label class="control-label">Email*</label>
                                    <input type="email" data-parsley-required-message="The email field is required" name="email" value="{{ old('email', $user->email) }}" class="form-control {{ $errors->has('email') ? 'is-invalid' : '' }}" autocomplete="off" placeholder="Enter Your Email" disabled required>
                                    @if ($errors->has('email'))
                                    <span class="text-danger">{{ $errors->first('email') }}</span>
                                    @endif
                                </div>

                                <div class="col-md-6 mb-3">
                                    <label class="control-label">Phone*</label>
                                    <input class="form-control" type="text" name="phone" value="{{ old('phone', @$user->phone) }}" data-parsley-required-message="The phone field is required" data-parsley-trigger="keyup" data-parsley-validation-threshold="1" data-parsley-debounce="500" data-parsley-type="digits" data-parsley-minlength="11" data-parsley-maxlength="15" required placeholder="Enter Phone">
                                </div>
                            </div>

                            <button type="submit" class="btn btn-success">Save</button>
                        </form>
                    </div>
                </div>
            </div>

            <!-- Change Password -->
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header bg-inverse text-white">
                        <h4 class="m-b-0 text-white d-inline-block">Change Password</h4>
                    </div>

                    <div class="card-body">
                        <form action="{{ route('credential.update') }}" method="POST" data-parsley-validate>
                            @csrf

                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label class="control-label">Current Password*</label>
                                    <input type="password" name="current_password" data-parsley-required-message="The current password field is required" id="password" value="{{ old('current_password') }}" class="form-control {{ $errors->has('current_password') ? 'is-invalid' : '' }}" autocomplete="off" placeholder="Enter Current Password" required>
                                    @error('current_password')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>

                                <div class="col-md-6 mb-3">
                                    <label class="control-label">New Password*</label>
                                    <input type="password" name="password" data-parsley-required-message="The new password field is required" data-parsley-minlength="8" data-parsley-maxlength="15" value="{{ old('password') }}" class="form-control @error('password') is-invalid @enderror" id="pwd-password" autocomplete="off" placeholder="Enter New Password" required>

                                    @error('password')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>

                                <div class="col-md-6 mb-3">
                                    <label class="control-label">Confirm Password*</label>
                                    <input type="password" name="password_confirmation" data-parsley-required-message="The confirmation password field is required" data-parsley-minlength="8" data-parsley-maxlength="15" value="{{ old('password_confirmation') }}" class="form-control @error('password_confirmation') is-invalid @enderror" id="cnfm-password" autocomplete="off" placeholder="Enter Confirm Password" required>

                                    @error('password_confirmation')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>

                            </div>
                            <button type="submit" class="btn btn-success">Save</button>
                        </form>
                    </div>
                </div>
            </div>

        </div>

    </div>
</div>
@endsection