<?php

use App\Http\Controllers\AffiliatedLinkController;
use App\Http\Controllers\AnnouncementController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\CommunityController;
use App\Http\Controllers\ContentController;
use App\Http\Controllers\CourseController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\EventController;
use App\Http\Controllers\FaqsController;
use App\Http\Controllers\ProgramController;
use App\Http\Controllers\SocialLinkController;
use App\Http\Controllers\SupportController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\UserProfileController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Log;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Log::info('--------------start-------------------');
Log::info(@$_SERVER['HTTP_AUTHORIZATION']);
Log::info(request()->fullUrl());
Log::info(@$_SERVER['REQUEST_METHOD']);
Log::info(json_encode(request()->all()));

Route::group(   ['prefix' => 'manager', 'namespaces' => 'App\Http\Controllers\Restaurant'],
 function() {
    Route::get('/', [AuthController::class, 'login']);
    Route::post('/', [AuthController::class, 'login'])->name('manager.login')->middleware("throttle:3,2");

    Route::post('/forgot-password', [AuthController::class, 'forgotPassword'])->name('manager.forgot');

    Route::group(['middleware' => 'auth:web'], function() {

        Route::get('/dashboard', [DashboardController::class, 'index']);

        Route::resource('/affiliates', AffiliatedLinkController::class);
        Route::resource('/socials', SocialLinkController::class);
        Route::resource('/faqs', FaqsController::class);
        Route::resource('/contents', ContentController::class);

        Route::get('/supports', [SupportController::class, 'index']);
        Route::get('/supports/{id}', [SupportController::class, 'show']);

        Route::resource('/courses', CourseController::class);
        Route::resource('/users', UserController::class);

        Route::resource('/settings', UserProfileController::class);
        Route::post('/credential', [AuthController::class, 'updateCredential'])->name('credential.update');

        Route::resource('/communities', CommunityController::class);
        Route::post('communities/{id}/update', [CommunityController::class, 'update']);

        Route::resource('/programs', ProgramController::class);

        Route::get('/events', [EventController::class, 'index']);
        Route::post('/event/store', [EventController::class, 'store']);
        Route::get('/events/participates', [EventController::class, 'eventParticipate']);
        Route::get('/events/participates/{id}', [EventController::class, 'participateShow']);

        Route::get('/announcements', [AnnouncementController::class, 'index']);
        Route::get('/announcements/store', [AnnouncementController::class, 'store']);
        Route::post('/announcements/store', [AnnouncementController::class, 'store']);
        Route::delete('/announcements/{id}/delete', [AnnouncementController::class, 'destroy']);

        Route::get('/logout', [AuthController::class, 'logout'])->name('logout');
    });
});

